nxp-pac

Crates

git

Versions

mcxa256

Flavors

Fircvld

Enum Fircvld 

#[repr(u8)]
pub enum Fircvld { NOT_ENABLED_OR_NOT_VALID = 0, ENABLED_AND_VALID = 1, }

Variants



NOT_ENABLED_OR_NOT_VALID = 0

FIRC is not enabled or clock is not valid.



ENABLED_AND_VALID = 1

FIRC is enabled and output clock is valid. The clock is valid after there is an output clock from the FIRC analog.

Implementations

Source

impl Fircvld

pub const fn from_bits(val: u8) -> Fircvld

pub const fn to_bits(self) -> u8